==> risk-center-api-0.4.36-20190516.111443-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskMaterialSignDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 广告素材所属行业标记表
*/
public class RiskMaterialSignDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 
    */
    private Long id;

    /**
    * 竞品id
    */
    private Long competeId;

    /**
    * 竞品巡查日志id
    */
    private Long competeLogId;

    /**
    * 行业
    */
    private String industryName;

    /**
    * 广告素材序号
    */
    private Integer materialNum;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setCompeteId(Long competeId) {
        this.competeId = competeId;
    }

    public Long getCompeteId() {
        return competeId;
    }

    public void setCompeteLogId(Long competeLogId) {
        this.competeLogId = competeLogId;
    }

    public Long getCompeteLogId() {
        return competeLogId;
    }

    public void setIndustryName(String industryName) {
        this.industryName = industryName;
    }

    public String getIndustryName() {
        return industryName;
    }

    public void setMaterialNum(Integer materialNum) {
        this.materialNum = materialNum;
    }

    public Integer getMaterialNum() {
        return materialNum;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> risk-center-api-0.5.5-20190718.022823-4-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskMaterialSignDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 广告素材所属行业标记表
*/
public class RiskMaterialSignDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;

    /**
    * 竞品id
    */
    private Long competeId;

    /**
    * 竞品巡查日志id
    */
    private Long competeLogId;

    /**
    * 行业id
    */
    private Long industryId;

    /**
    * 广告素材序号
    */
    private Integer materialNum;

    /**
     * 修改者
     */
    private String editor;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCompeteId() {
        return competeId;
    }

    public void setCompeteId(Long competeId) {
        this.competeId = competeId;
    }

    public Long getCompeteLogId() {
        return competeLogId;
    }

    public void setCompeteLogId(Long competeLogId) {
        this.competeLogId = competeLogId;
    }

    public Long getIndustryId() {
        return industryId;
    }

    public void setIndustryId(Long industryId) {
        this.industryId = industryId;
    }

    public Integer getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(Integer materialNum) {
        this.materialNum = materialNum;
    }

    public String getEditor() {
        return editor;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
